
***************************
* File: personnel_sante.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\First Round\personnel_csb\personnel_sante.dta"

**************************************************
***    Ensure all variables are present and labeled.
**************************************************
cd "Source\First Round\personnel_csb"
log using "personnel_sante", replace
codebook, compact
log close

**************************************************
***  Ensure response value labels are correct.
**************************************************
label save using "personnel_sante label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen ID=concat( code_cs cod_pers)
destring ID, replace
order code_cs cod_pers ID
label var ID "identifiant unique"

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

log using "personnel_sante errors", replace
preserve
global name (qui)
drop  $name 
foreach v of varlist  an_pers-assoc{
	gen error01`v' = (present == 2 & `v'< . )
}
su err*
log close
restore


foreach v of varlist      categ cadre retard{
	gen error02`v' = (position == 2 & `v'< . )
}
 
gen error03maison = (maison == 1 & mis_disp< . )
gen error04maison = (maison == 2 & mis_disp< . )
gen error05non_paye = (non_paye ==2 & mois_non_p< . )

replace  nb_avce=. if mod_paie==1 & nb_avce==0
replace  nb_avce=. if mod_paie==2 & nb_avce==0
replace  nb_avce=. if mod_paie==4 & nb_avce==0
replace  nb_avce=. if mod_paie==5 & nb_avce==0

gen error06mod_paie = (mod_paie ==1 & nb_avce< . )
gen error07mod_paie = (mod_paie ==2 & nb_avce< . )
gen error08mod_paie = (mod_paie ==4 & nb_avce< . )
gen error09mod_paie = (mod_paie ==5 & nb_avce< . )

foreach v of varlist     dequi montant per_ind nature mod_nrt{
	gen error10`v' = (indemn == 2 & `v'< . )
}

**************************************************
***   Identify illegal responses
**************************************************

log using "personnel_sante label inspect", replace
inspect
log close

**************************************************
***    Identify outliers
**************************************************

log using "personnel_sante grubbs", replace
preserve
global name (nom_pers qui)
global discrete (present	retard	non_paye	indemn	position	cadre	formation	dern_form	origin	grandi	maison	mis_disp	transp	dequi	nature	aut_actv1	aut_actv2	aut_actv3	assoc	dipl_ac	situat	mod_paie	per_etat	per_ssd	per_com	per_autre	per_sec	per_plui	per_ind)
drop $discrete  $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
***   Identify errors to be reviewed
**************************************************

replace  non_paye=. if ID==71631112
replace  cadre=. if ID==30803122
replace  retard=. if ID==30803122
replace  retard=. if ID==71629122
replace  non_paye=1 if ID==30455123
replace  mod_paie=. if ID==10313128 | ID==10313127 | ID==10313129 | ID==51901125
replace  mod_paie=. if ID==10313122 | ID==10313121 | ID==10313125 | ID==10313123
replace  mod_paie=. if ID==10313126 
replace  nature=. if ID==11205112 | ID==11205111 | ID==11205121 | ID==11205122 | ID==11255122 | ID==11255123 | ID==11255121 | ID==30405121 | ID==51925121 | ID==71631124



**************************************************
***   Reviewing errors and computing responses
**************************************************
drop err* 

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\personnel_csb"
log using "personnel_sante codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\personnel_csb"
save personnel_sante_cleaned_data.dta, replace
